package cn.estsh.i3plus.pojo.wms.dbinterface;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Index;
import javax.persistence.Table;

/**
 * WMS - SAP 中间数据库接口映射关系
 *
 * @author Rock.Yu
 * @since 2019-06-09 20:08
 */
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Table(name = "WMS_INTERFACE_DATA_RECORD", indexes = {
        @Index(columnList = "ORGANIZE_CODE"),
        @Index(columnList = "SRC_TABLE_NAME"),
        @Index(columnList = "DEST_BEAN_NAME"),
        @Index(columnList = "SOFT_ADAPATOR_CODE"),
        @Index(columnList = "SID"),
        @Index(columnList = "MOVE_TO_ERP_ID")
})
@Api("接口数据收发记录")
public class WmsInterfaceDataRecord extends BaseBean {
    private static final long serialVersionUID = 4139055040492108499L;

    @ApiParam("来源表名")
    @Column(name = "SRC_TABLE_NAME", length = 50)
    public String srcTableName;

    @ApiParam("目标实体对象的名字，多个字段用半角逗号分隔")
    @Column(name = "DEST_BEAN_NAME", length = 500)
    public String destBeanName;

    @ApiParam("软适配编号")
    @Column(name = "SOFT_ADAPATOR_CODE")
    public String softAdaptorCode;

    @ApiParam("接口名称")
    @Column(name = "INTERFACE_NAME")
    public String interfaceName;

    @ApiParam("报文唯一编号")
    @Column(name = "SID")
    public Long sid;

    @ApiParam("MOVE_TO_ERP表的ID")
    @Column(name = "MOVE_TO_ERP_ID")
    public Long moveToErpID;

    @ApiParam("报文校验状态")
    @Column(name = "VERIFY_STATUS")
    @ColumnDefault("10")
    @AnnoOutputColumn(refClass = WmsEnumUtil.INTERFACE_DATA_VERIFY_STATUS.class, refForeignKey = "value", value = "description", required = false)
    public int verifyStatus;

    @ApiParam("备注信息")
    @Column(name = "REMARK")
    public String remark;
}
